import searchReducer from '@/redux/search/search.slice';
import type { SearchState } from '@/redux/search/search.types';
import { ToolkitStoreWithSingleSlice } from '@/utils/createStoreInstanceUsingSliceReducer';
import { getReduxWrapperUsingSliceReducer } from '@/utils/testing/getReduxWrapperUsingSliceReducer';
import { fireEvent, render, screen } from '@testing-library/react';
import { SearchBar } from './SearchBar.component';

const renderComponent = (): { store: ToolkitStoreWithSingleSlice<SearchState> } => {
  const { Wrapper, store } = getReduxWrapperUsingSliceReducer('search', searchReducer);

  return (
    render(
      <Wrapper>
        <SearchBar />
      </Wrapper>,
    ),
    {
      store,
    }
  );
};

describe('SearchBar - component', () => {
  it('should let user type text', () => {
    renderComponent();

    const input = screen.getByTestId<HTMLInputElement>('search-input');
    fireEvent.change(input, { target: { value: 'test value' } });

    expect(input.value).toBe('test value');
  });

  it('should disable button when the user clicks the lens button', () => {
    renderComponent();

    const input = screen.getByTestId<HTMLInputElement>('search-input');
    fireEvent.change(input, { target: { value: 'park7' } });

    expect(input.value).toBe('park7');

    const button = screen.getByRole('button');
    fireEvent.click(button);

    expect(button).toBeDisabled();
  });

  it('should disable input when the user clicks the Enter', () => {
    renderComponent();

    const input = screen.getByTestId<HTMLInputElement>('search-input');
    fireEvent.change(input, { target: { value: 'park7' } });

    expect(input.value).toBe('park7');

    fireEvent.keyDown(input, { key: 'Enter', code: 'Enter', charCode: 13 });

    expect(input).toBeDisabled();
  });
});
