import lensIcon from '@/assets/vectors/icons/lens.svg';
import { useAppDispatch } from '@/redux/hooks/useAppDispatch';
import {
  isPendingSearchStatusSelector,
  searchValueSelector,
} from '@/redux/search/search.selectors';
import { getSearchData } from '@/redux/search/search.thunks';
import Image from 'next/image';
import { ChangeEvent, KeyboardEvent, useState } from 'react';
import { useSelector } from 'react-redux';

const ENTER_KEY_CODE = 'Enter';

export const SearchBar = (): JSX.Element => {
  const [searchValue, setSearchValue] = useState<string>('');
  const dispatch = useAppDispatch();
  const isPendingSearchStatus = useSelector(isPendingSearchStatusSelector);
  const prevSearchValue = useSelector(searchValueSelector);

  const isSameSearchValue = prevSearchValue === searchValue;

  const onSearchChange = (event: ChangeEvent<HTMLInputElement>): void =>
    setSearchValue(event.target.value);

  // eslint-disable-next-line @typescript-eslint/explicit-function-return-type
  const onSearchClick = () => !isSameSearchValue && dispatch(getSearchData(searchValue));

  const handleKeyPress = (event: KeyboardEvent<HTMLInputElement>): void => {
    if (!isSameSearchValue && event.code === ENTER_KEY_CODE) dispatch(getSearchData(searchValue));
  };

  return (
    <div className="relative" data-testid="search-bar">
      <input
        value={searchValue}
        name="search-input"
        aria-label="search-input"
        data-testid="search-input"
        onKeyDown={handleKeyPress}
        onChange={onSearchChange}
        disabled={isPendingSearchStatus}
        className="h-9 w-72 rounded-[64px] border border-transparent bg-cultured px-4 py-2.5 text-xs font-medium text-font-400 outline-none  hover:border-greyscale-600 focus:border-greyscale-600"
      />
      <button
        disabled={isPendingSearchStatus}
        type="button"
        className="bg-transparent"
        onClick={onSearchClick}
      >
        <Image
          src={lensIcon}
          alt="lens icon"
          height={16}
          width={16}
          className="absolute right-4 top-2.5"
        />
      </button>
    </div>
  );
};
