import { z } from 'zod';
import { referenceSchema } from './referenceSchema';
import { authorSchema } from './authorSchema';

export const modelSchema = z.object({
  /** name of the map */
  name: z.string(),
  description: z.string(),
  /** map id */
  idObject: z.number(),
  /** map width */
  width: z.number(),
  /** map height */
  height: z.number(),
  /** size of the png tile used to visualize in frontend */
  tileSize: z.number(),
  /** default x center used in frontend visualization */
  defaultCenterX: z.union([z.number(), z.null()]),
  /** default y center used in frontend visualization */
  defaultCenterY: z.union([z.number(), z.null()]),
  /** default zoom level used in frontend visualization */
  defaultZoomLevel: z.union([z.number(), z.null()]),
  /** minimum zoom level availbale for the map */
  minZoom: z.number(),
  /** maximum zoom level available for the map */
  maxZoom: z.number(),
  authors: z.array(authorSchema),
  references: z.array(referenceSchema),
  creationDate: z.union([z.string(), z.null()]),
  modificationDates: z.array(z.string()),
});
