import { bioEntityContentsFixture } from '@/models/fixtures/bioEntityContentsFixture';
import { mockNetworkResponse } from '@/utils/mockNetworkResponse';
import {
  ToolkitStoreWithSingleSlice,
  createStoreInstanceUsingSliceReducer,
} from '@/utils/createStoreInstanceUsingSliceReducer';
import { HttpStatusCode } from 'axios';
import { apiPath } from '@/redux/apiPath';
import { getBioEntityContents } from './bioEntityContents.thunks';
import bioEntityContentsReducer from './bioEntityContents.slice';
import { BioEntityContentsState } from './bioEntityContents.types';

const mockedAxiosClient = mockNetworkResponse();
const SEARCH_QUERY = 'park7';

const INITIAL_STATE: BioEntityContentsState = {
  data: [],
  loading: 'idle',
  error: { name: '', message: '' },
};

describe('bioEntityContents reducer', () => {
  let store = {} as ToolkitStoreWithSingleSlice<BioEntityContentsState>;
  beforeEach(() => {
    store = createStoreInstanceUsingSliceReducer('bioEntityContents', bioEntityContentsReducer);
  });

  it('should match initial state', () => {
    const action = { type: 'unknown' };

    expect(bioEntityContentsReducer(undefined, action)).toEqual(INITIAL_STATE);
  });
  it('should update store after succesfull getBioEntityContents query', async () => {
    mockedAxiosClient
      .onGet(apiPath.getBioEntityContentsStringWithQuery(SEARCH_QUERY))
      .reply(HttpStatusCode.Ok, bioEntityContentsFixture);

    const { type } = await store.dispatch(getBioEntityContents(SEARCH_QUERY));
    const { data, loading, error } = store.getState().bioEntityContents;

    expect(type).toBe('project/getBioEntityContents/fulfilled');
    expect(loading).toEqual('succeeded');
    expect(error).toEqual({ message: '', name: '' });
    expect(data).toEqual(bioEntityContentsFixture);
  });

  it('should update store after failed getBioEntityContents query', async () => {
    mockedAxiosClient
      .onGet(apiPath.getBioEntityContentsStringWithQuery(SEARCH_QUERY))
      .reply(HttpStatusCode.NotFound, bioEntityContentsFixture);

    const { type } = await store.dispatch(getBioEntityContents(SEARCH_QUERY));
    const { data, loading, error } = store.getState().bioEntityContents;

    expect(type).toBe('project/getBioEntityContents/rejected');
    expect(loading).toEqual('failed');
    expect(error).toEqual({ message: '', name: '' });
    expect(data).toEqual([]);
  });

  it('should update store on loading getBioEntityContents query', async () => {
    mockedAxiosClient
      .onGet(apiPath.getBioEntityContentsStringWithQuery(SEARCH_QUERY))
      .reply(HttpStatusCode.Ok, bioEntityContentsFixture);

    const bioEntityContentsPromise = store.dispatch(getBioEntityContents(SEARCH_QUERY));

    const { data, loading } = store.getState().bioEntityContents;
    expect(data).toEqual([]);
    expect(loading).toEqual('pending');

    bioEntityContentsPromise.then(() => {
      const { data: dataPromiseFulfilled, loading: promiseFulfilled } =
        store.getState().bioEntityContents;

      expect(dataPromiseFulfilled).toEqual(bioEntityContentsFixture);
      expect(promiseFulfilled).toEqual('succeeded');
    });
  });
});
