import { z } from 'zod';
import { createAsyncThunk } from '@reduxjs/toolkit';
import { axiosInstance } from '@/services/api/utils/axiosInstance';
import { BioEntityContent } from '@/types/models';
import { bioEntityContentSchema } from '@/models/bioEntityContentSchema';
import { validateDataUsingZodSchema } from '@/utils/validateDataUsingZodSchema';
import { apiPath } from '@/redux/apiPath';

export const getBioEntityContents = createAsyncThunk(
  'project/getBioEntityContents',
  async (searchQuery: string): Promise<BioEntityContent[] | undefined> => {
    const response = await axiosInstance.get<BioEntityContent[]>(
      apiPath.getBioEntityContentsStringWithQuery(searchQuery),
    );

    const isDataValid = validateDataUsingZodSchema(response.data, z.array(bioEntityContentSchema));

    return isDataValid ? response.data : undefined;
  },
);
