import { z } from 'zod';
import { createAsyncThunk } from '@reduxjs/toolkit';
import { axiosInstance } from '@/services/api/utils/axiosInstance';
import { Mirna } from '@/types/models';
import { mirnaSchema } from '@/models/mirnaSchema';
import { validateDataUsingZodSchema } from '@/utils/validateDataUsingZodSchema';
import { apiPath } from '@/redux/apiPath';

export const getMirnas = createAsyncThunk(
  'project/getMirnas',
  async (searchQuery: string): Promise<Mirna[] | undefined> => {
    const response = await axiosInstance.get<Mirna[]>(
      apiPath.getMirnasStringWithQuery(searchQuery),
    );

    const isDataValid = validateDataUsingZodSchema(response.data, z.array(mirnaSchema));

    return isDataValid ? response.data : undefined;
  },
);
