import { z } from 'zod';
import { createAsyncThunk } from '@reduxjs/toolkit';
import { axiosInstance } from '@/services/api/utils/axiosInstance';
import { Model } from '@/types/models';
import { validateDataUsingZodSchema } from '@/utils/validateDataUsingZodSchema';
import { apiPath } from '@/redux/apiPath';
import { modelSchema } from '@/models/modelSchema';

export const getModels = createAsyncThunk(
  'project/getModels',
  async (): Promise<Model[] | undefined> => {
    const response = await axiosInstance.get<Model[]>(apiPath.getModelsString());

    const isDataValid = validateDataUsingZodSchema(response.data, z.array(modelSchema));

    return isDataValid ? response.data : undefined;
  },
);
