import { StoreType } from '@/redux/store';
import { configureStore } from '@reduxjs/toolkit';
import { Provider } from 'react-redux';
import bioEntityContentsReducer from '@/redux/bioEntityContents/bioEntityContents.slice';
import chemicalsReducer from '@/redux/chemicals/chemicals.slice';
import drawerReducer from '@/redux/drawer/drawer.slice';
import drugsReducer from '@/redux/drugs/drugs.slice';
import mirnasReducer from '@/redux/mirnas/mirnas.slice';
import projectReducer from '@/redux/project/project.slice';
import searchReducer from '@/redux/search/search.slice';
import modelsReducer from '@/redux/models/models.slice';
import { SearchState } from '@/redux/search/search.types';
import { ProjectState } from '@/redux/project/project.types';
import { DrugsState } from '@/redux/drugs/drugs.types';
import { MirnasState } from '@/redux/mirnas/mirnas.types';
import { ChemicalsState } from '@/redux/chemicals/chemicals.types';
import { BioEntityContentsState } from '@/redux/bioEntityContents/bioEntityContents.types';
import { DrawerState } from '@/redux/drawer/drawer.types';

interface WrapperProps {
  children: React.ReactNode;
}

export type InitialStoreState = {
  search?: SearchState;
  project?: ProjectState;
  drugs?: DrugsState;
  mirnas?: MirnasState;
  chemicals?: ChemicalsState;
  bioEntityContents?: BioEntityContentsState;
  drawer?: DrawerState;
};

type GetReduxWrapperUsingSliceReducer = (initialState?: InitialStoreState) => {
  Wrapper: ({ children }: WrapperProps) => JSX.Element;
  store: StoreType;
};

export const getReduxWrapperWithStore: GetReduxWrapperUsingSliceReducer = (
  preloadedState: InitialStoreState = {},
) => {
  const testStore = configureStore({
    reducer: {
      search: searchReducer,
      project: projectReducer,
      drugs: drugsReducer,
      mirnas: mirnasReducer,
      chemicals: chemicalsReducer,
      bioEntityContents: bioEntityContentsReducer,
      drawer: drawerReducer,
      models: modelsReducer,
    },
    preloadedState,
  });

  const Wrapper = ({ children }: WrapperProps): JSX.Element => (
    <Provider store={testStore}>{children}</Provider>
  );

  return { Wrapper, store: testStore };
};
